# -*- coding: utf-8 -*-
"""
    author: jiege
    url: http://jieguone.top
    copyright: © jieguone.top
    license: none
    date : 2019/4/3 23:11
    ide : PyCharm
"""
import time


class DateTime:

    def __init__(self, thisDate=0):
        self.thisDate = thisDate

    def __str__(self):
        return time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(self.thisDate))

    def ToString(self, str_format='%Y-%m-%d %H:%M:%S'):
        return time.strftime(str_format, time.localtime(self.thisDate))

    @staticmethod
    def Now():
        return DateTime(thisDate=time.time())

    def AddDays(self, days):
        return DateTime(thisDate=self.thisDate + days * 86400)

    def AddHours(self, hours):
        return DateTime(thisDate=self.thisDate + hours * 3600)

    def AddMinutes(self, minutes):
        return DateTime(thisDate=self.thisDate + minutes * 60)

    def AddSecond(self, seconds):
        return DateTime(thisDate=self.thisDate + seconds)


# if __name__ == '__main__':
#     date = DateTime.Now().AddMinutes(-1)
#     print(date.ToString())


# -*- coding: utf-8 -*-
"""
    author: jiege
    url: http://jieguone.top
    copyright: © jieguone.top
    license: none
    date : 2019/4/8 20:34
    ide : PyCharm
"""
import logging
import os
from logging import handlers
from jgpycshare.DateTime import DateTime


class LogTools(object):

    @staticmethod
    def get_logger(channel__name, level):
        filename = DateTime.Now().ToString('%Y%m%d')
        filepath = os.getcwd() + '/Log/' + channel__name
        if not os.path.exists(filepath):
            os.makedirs(filepath)
        log = LogTools(filepath + '/' + filename + '.txt', level=level)
        return log.logger

    level_relations = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'crit': logging.CRITICAL
    }  # 日志级别关系映射

    def __init__(self, filename, level='info', when='D', backCount=100, fmt='[%(asctime)s]-%(levelname)s:%(message)s'):
        self.logger = logging.getLogger(filename)
        format_str = logging.Formatter(fmt)  # 设置日志格式
        self.logger.setLevel(self.level_relations.get(level))  # 设置日志级别
        sh = logging.StreamHandler()  # 往屏幕上输出
        sh.setFormatter(format_str)  # 设置屏幕上显示的格式
        th = handlers.TimedRotatingFileHandler(filename=filename, when=when, backupCount=backCount,
                                               encoding='utf-8')  # 往文件里写入#指定间隔时间自动生成文件的处理器
        # 实例化TimedRotatingFileHandler
        # interval是时间间隔，backupCount是备份文件的个数，如果超过这个个数，就会自动删除，when是间隔的时间单位，单位有以下几种：
        # S 秒
        # M 分
        # H 小时、
        # D 天、
        # W 每星期（interval==0时代表星期一）
        # midnight 每天凌晨
        th.setFormatter(format_str)  # 设置文件里写入的格式
        self.logger.addHandler(sh)  # 把对象加到logger里
        self.logger.addHandler(th)


# if __name__ == '__main__':
#     log = LogTools.get_logger('info','info')
#     log.info('asdfsadf')


# -*- coding: utf-8 -*-
"""
    author: jiege
    url: http://jieguone.top
    copyright: © jieguone.top
    license: none
    date : 2019/4/4 0:31
    ide : PyCharm
"""

class logtool:

    def info(self, strLog):
        """
            author: jiege
            url: http://jieguone.top
            copyright: © jieguone.top
            license: none
            date : 2019/4/4 0:31
            ide : PyCharm
        """
        print(strLog)


from Crypto.PublicKey import RSA
from Crypto.Signature import PKCS1_v1_5
from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
from Crypto.Hash import SHA256
import base64
from Crypto.Cipher import AES
# from Crypto import Random


class JGRSA:

    def __init__(self,app_private_key_path=None,app_public_key_path=None):
        self.app_private_key = None
        self.app_public_key = None

        if app_private_key_path is not None:
            with open(app_private_key_path) as fp:
                self.app_private_key = RSA.importKey(fp.read())

        if app_public_key_path is not None:
            with open(app_public_key_path) as fp:
                self.app_public_key = RSA.importKey(fp.read())

    def ali_pri_sign(self, unsigned_string):
        unsigned_string = unsigned_string.encode("utf-8")
        key = self.app_private_key
        signer = PKCS1_v1_5.new(key)
        # base64 编码，转换为unicode表示并移除回车
        signature = signer.sign(SHA256.new(unsigned_string))
        signed = base64.encodebytes(signature).decode("utf8").replace("\n", "")
        return signed

    def _verify(self, raw_content, signature):
        # 开始计算签名
        key = self.app_public_key
        signer = PKCS1_v1_5.new(key)
        digest = SHA256.new()
        digest.update(raw_content.encode("utf8"))
        if signer.verify(digest, base64.decodebytes(signature.encode("utf8"))):
            return True
        return False

    def ali_pub_check_sign(self, data, signature):
        return self._verify(data, signature)

    def pub_encode(self, encodestr):
        encodestr = encodestr.encode("utf-8")
        rsakey = self.app_public_key
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        cipher_text = base64.b64encode(cipher.encrypt(encodestr))
        print(cipher_text)
        return cipher_text

    def pri_decode(self, decodestr):
        rsakey = self.app_private_key
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        # random_generator = Random.new().read
        text = cipher.decrypt(base64.b64decode(decodestr), None)
        return text.decode('utf8')

    @staticmethod
    def ali_pub_check_signfor_key(data, signature, pubkey):
         # 开始计算签名
        key = RSA.importKey(pubkey)
        signer = PKCS1_v1_5.new(key)
        digest = SHA256.new()
        digest.update(data.encode("utf8"))
        if signer.verify(digest, base64.decodebytes(signature.encode("utf8"))):
            return True
        return False

    @staticmethod
    def ali_pri_sign_key(unsigned_string, prikey):
        prikey = RSA.importKey(prikey)
        unsigned_string = unsigned_string.encode("utf-8")
        signer = PKCS1_v1_5.new(prikey)
        # base64 编码，转换为unicode表示并移除回车
        signature = signer.sign(SHA256.new(unsigned_string))
        signed = base64.encodebytes(signature).decode("utf8").replace("\n", "")
        return signed

    @staticmethod
    def pri_decode_key(decodestr, prikey):
        rsakey = RSA.importKey(prikey)
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        # random_generator = Random.new().read
        text = cipher.decrypt(base64.b64decode(decodestr), None)
        return text.decode('utf8')

    @staticmethod
    def pub_encode_key(encodestr, pubkey):
        rsakey = RSA.importKey(pubkey)
        encodestr = encodestr.encode("utf-8")
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        cipher_text = base64.b64encode(cipher.encrypt(encodestr))
        print(cipher_text)
        return cipher_text


class JGAES:
    def __init__(self, key):
        self.key = key
        self.mode = AES.MODE_CBC
 
    def encrypt(self, text):
        import base64
        cryptor = AES.new(self.key, self.mode, self.key)
        length = 16                    
        count = len(text.encode('utf-8'))    
        print(count)               
        if (count % length != 0):
            add = length - (count % length)
        else:
            add = 0            
        text1 = text + ('\0' * add)    
        self.ciphertext = cryptor.encrypt(text1)        
        cryptedStr = str(base64.b64encode(self.ciphertext),encoding='utf-8')
        return cryptedStr
      
 
 
    def decrypt(self, text):
        import base64, json
        base_text = base64.b64decode(text)
        cryptor = AES.new(self.key, self.mode, self.key)
        plain_text = cryptor.decrypt(base_text)
        ne = plain_text.decode('utf-8').rstrip('\0')
        return ne


# -*- coding: utf-8 -*-
"""
    author: jiege
    url: http://jieguone.top
    copyright: © jieguone.top
    license: none
    date : 2019/4/4 20:57
    ide : PyCharm
"""
import hashlib


class StringTools:
    @staticmethod
    def get_login_pass(value):
        return StringTools.get_md5_utf8('e10adc3949ba59abbe56e057f20f883e' + value)

    @staticmethod
    def get_md5_utf8(value):
        return hashlib.md5(value.encode(encoding='UTF-8')).hexdigest()